"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __asyncValues = (this && this.__asyncValues) || function (o) {
    if (!Symbol.asyncIterator) throw new TypeError("Symbol.asyncIterator is not defined.");
    var m = o[Symbol.asyncIterator], i;
    return m ? m.call(o) : (o = typeof __values === "function" ? __values(o) : o[Symbol.iterator](), i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i);
    function verb(n) { i[n] = o[n] && function (v) { return new Promise(function (resolve, reject) { v = o[n](v), settle(resolve, reject, v.done, v.value); }); }; }
    function settle(resolve, reject, d, v) { Promise.resolve(v).then(function(v) { resolve({ value: v, done: d }); }, reject); }
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.conduct = void 0;
const chalk_1 = __importDefault(require("chalk"));
const git_changed_files_1 = __importDefault(require("git-changed-files"));
const ora_1 = __importDefault(require("ora"));
const config_1 = require("../config");
const log_1 = require("../helpers/log");
const organize_imports_1 = require("./organize-imports");
const get_files_paths_1 = require("./get-files-paths");
const organize_imports_2 = require("./organize-imports");
function conduct(configuration) {
    var e_1, _a;
    return __awaiter(this, void 0, void 0, function* () {
        const config = config_1.resolveConfig(configuration);
        config_1.setConfig(config);
        const { staged, source, verbose, ignore, dryRun } = config;
        const filePaths = staged ? (yield git_changed_files_1.default({ showCommitted: false })).unCommittedFiles : get_files_paths_1.getFilesPaths(source);
        if (filePaths.length === 0) {
            const msg = staged ? 'No staged files found' : `No matching files for regex: "${source}"`;
            console.log(chalk_1.default.yellow(`⚠️ ${msg}`));
            return [];
        }
        dryRun && console.log('🧪 Dry run 🧪');
        let spinner = verbose ? null : ora_1.default('Conducting imports').start();
        const results = {
            [organize_imports_2.actions.skipped]: 0,
            [organize_imports_2.actions.reordered]: 0,
        };
        try {
            for (var filePaths_1 = __asyncValues(filePaths), filePaths_1_1; filePaths_1_1 = yield filePaths_1.next(), !filePaths_1_1.done;) {
                const path = filePaths_1_1.value;
                const ignoreFile = ignore.includes(path) || ignore.some((p) => path.includes(p));
                if (ignoreFile) {
                    results[organize_imports_2.actions.skipped]++;
                    log_1.log('gray', 'skipped (via ignore pattern)', path);
                    continue;
                }
                const actionDone = yield organize_imports_1.organizeImportsForFile(path);
                if (actionDone in results) {
                    results[actionDone]++;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (filePaths_1_1 && !filePaths_1_1.done && (_a = filePaths_1.return)) yield _a.call(filePaths_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        let messages = [];
        const reorderMessage = results.reordered === 0 ? '✨ No changes needed in all the files.' : `🔀 ${results.reordered} file imports were reordered.`;
        messages.push(reorderMessage);
        if (results.skipped > 0) {
            messages.push(`🦘 ${results.skipped} file${results.skipped > 1 ? 's were' : ' was'} skipped.`);
        }
        spinner === null || spinner === void 0 ? void 0 : spinner.succeed(`Conducting imports - done!`);
        return messages;
    });
}
exports.conduct = conduct;
//# sourceMappingURL=conduct.js.map